@@ -634,9 +634,6 @@ def _convert(res, columns):
     else:    
         return np.array(values) if is_int(columns) else pd.Series(res)
 
-def df_roll(chain, ub = 'ub', funcs = None):
-    pass
-
 def df_sync(dfs, join = 'ij', method = None, columns = 'ij'):
     """
     df_sync performs a sync of multiple dataframes
